@@ -24,7 +24,11 @@ def initialize():
         _initialzied = True
 
 
+Subnet = IPBlock
+IPAddr = IPBlock
+IPContainer = IPBlock
+
 __all__ = [
-    'initialize', 'Asset', 'Device', 'Interface', 'IPBlock',
+    'initialize', 'Asset', 'Device', 'Interface', 'IPBlock', 'Subnet', 'IPAddr', 'IPContainer',
     'Product', 'ProductType', 'Site', 'VLAN', 'NetdotAPIDataclass',
 ]
