@@ -1,16 +1,15 @@
 import logging
 from dataclasses import dataclass
-from typing import Dict, List
+from typing import List
 
-from netdot import defaults, parse
+import netdot.dataclasses
 from netdot.csv_util import CSVDataclass
 from netdot.dataclasses.base import NetdotAPIDataclass
-import netdot.dataclasses
 
 logger = logging.getLogger(__name__)
 
 
-@dataclass()
+@dataclass
 class Site(NetdotAPIDataclass, CSVDataclass):
     NETDOT_MENU_URL_PATH = 'cable_plant'
     NETDOT_TABLE_NAME = 'Site'
@@ -31,12 +30,3 @@ class Site(NetdotAPIDataclass, CSVDataclass):
     zip: str = None
     pobox: str = None
     info: str = None
-    _devices: List['netdot.dataclasses.Device'] = None
-
-    def with_alternate_name(self, name: str):
-        self.name = name
-        return self
-
-    def with_comment(self, comment):
-        self.info = comment
-        return self
