@@ -54,3 +54,12 @@ def test_create_object_site(client: Client):
 
     # Assert
     assert_that(site['name']).is_equal_to('Test site 123')
+
+
+@pytest.mark.vcr()
+def test_delete(client: Client):
+    # Act
+    client.delete_object_by_id("site", 738)
+
+    # Assert
+    assert_that(client.get_object_by_id).raises(ValueError).when_called_with('site', 738)
