@@ -3,6 +3,23 @@ from assertpy import assert_that
 import netdot.dataclasses as dataclasses
 
 
+def test_replace():
+    # Arrange
+    dataclasses.initialize()
+    site = dataclasses.Site(
+        name='Test netdot-sites-manager package', 
+        info="""Created to test the netdot-sites-manager Python package. 
+            See more in the project's user guide: 
+            https://git.uoregon.edu/projects/ISN/repos/netdot-sites-manager/browse/docs/user-guide.md"""
+    )
+
+    # Act
+    updated_site = site.replace(name=f'UPDATED: {site.name}')
+
+    # Assert
+    assert_that(updated_site.name).starts_with('UPDATED: ')
+
+
 def test_Device_initialization():
     # Act
     dataclasses.initialize()
